@@ -243,6 +243,32 @@ test_that("error messages work for area_profiles", {
                      "CB1 not in area_code field provided")
 })
 
+test_that("warning messages work for area_profiles", {
+        expect_warning(area_profiles(df_dps,
+                                     value = Value,
+                                     count = Count,
+                                     area_code = AreaCode,
+                                     local_area_code = "AC122",
+                                     indicator = IndicatorName,
+                                     timeperiod = Timeperiod,
+                                     polarity = Polarity,
+                                     significance = Significance,
+                                     area_type = AreaType,
+                                     median_line_area_code = "C001",
+                                     comparator_area_code = "PAC12",
+                                     datatable = TRUE,
+                                     relative_domain_text_size = 0.75,
+                                     relative_text_size = 1.2,
+                                     bar_width = 0.68,
+                                     indicator_label_nudgex = -0.1,
+                                     show_dividers = "outer",
+                                     header_positions = c(-0.7, -0.44, -0.35, -0.25,
+                                                          -0.15, -0.05, 0.9),
+                                     dps = NA),
+                     "Some bars may not display if the final value of the header_positions argument is less than 1")
+
+})
+
 df_preprocess_test <- spine_preprocess(df_preprocess,
                                        IndicatorName,
                                        TimeperiodSortable)
